import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { FormGroup, Validators, FormBuilder, FormControl } from '@angular/forms';
import { Router } from '@angular/router';
import { concatMap, tap } from 'rxjs';
import { environment } from 'src/environments/environment';

@Component({
    selector: 'app-advertise-analysis',
    templateUrl: './advertise-analysis.component.html',
    styleUrls: ['./advertise-analysis.component.scss']
})
export class AdvertiseAnalysisComponent implements OnInit {

    analysisLoading = false;
    analysisStart = false;
    correctedText!: string;
    error = false;
    randomSampleList = [
        "Szanowny Panie/Pani, mamy dla Pana/Pani niesamowitą nowość, która z pewnością przyciągnie Pana/Panią uwagę!",
        "Czy jest Pani/Pan gotowy/a na nową przygodę? Przygotowaliśmy dla Pani/Pana niezwykłe wyzwanie!",
        "Zapraszamy Pana/Panią do odkrycia tajemniczego świata pełnego fascynujących możliwości i niezwykłych przygód!",
        "Yo, co tam! Chciałem Ci dać cynk, że mamy dla Ciebie ekstra opcję, która rozbuja temat!",
        "Cześć, zajawkowiczu/zajawkowiczko! Mamy dla Ciebie mega ofertę, która da Ci czadu!",
        "Witam serdecznie! Wpadaj, bo mamy dla Ciebie niezłą promkę - czeka na Ciebie coś naprawdę wyjebanego!",
        "Hejka! Przygotowaliśmy dla Ciebie spoko gratkę, która odjazdowo kopnie!",
        "Elo, szanowna śmietanko/szanowny kumplu! Mamy dla Ciebie niezłe combo, które wgniata w fotel!",
        "Gratuluję osiągnięcia! To jest bardzo ważne dla mnie.",
        "Bardzo mi miło cię poznać. Bądź ostrożny i dbaj o siebie.",
        "Przepraszam za spóźnienie. Cieszę się, że mogę być tutaj.",
        "To jest naprawdę interesujące. Mam pytanie odnośnie twojej propozycji.",
        "Z radością przekazujemy wam najnowsze promocje!",
        "Dawaj, zróbmy sobie mały chillout. Zamówmy pizzę i obejrzyjmy jakiś dobry film.",
        "Wpadaj na piwko wieczorem, będziemy rozkręcać imprezę!",
        "Co tam u ciebie siedzi w lodówce? Może coś dobrego znajdziemy.",
        "Czaisz, o co chodzi? Nie ma potrzeby tłumaczyć ci wszystkiego po raz kolejny.",
        "Dogadaliśmy się w końcu i ustaliliśmy plan na resztę tygodnia.",
        "Przestań trząść portkami. Nie ma się czego bać.",
        "Walnijmy wreszcie prosto z mostu i powiedzmy sobie wszystko, co mamy na sercu."

    ]
    errorsForm: FormGroup = this.fb.group({
        text: ['', Validators.required]
    })
    constructor(
        private fb: FormBuilder,
        private http: HttpClient,
        private router: Router
    ) { }

    public get sentenceControl(): FormControl {
        return this.errorsForm.controls['text'] as FormControl
    }

    exampleOutput = {
        model1Label: 0,
        model2Label: ''
    }
    analysisResults = this.exampleOutput
    textDestiny: string = ''
    textIntrigue: string = ''
    textFormal: string = ''


    ngOnInit(): void {
    }

    analyseAdvert(isRandomSample: boolean): void {
        let sentence = ''
        this.analysisStart = true
        this.analysisLoading = false;
        this.error = false;
        if (isRandomSample) {
            const randomElement = this.randomSampleList[Math.floor(Math.random() * this.randomSampleList.length)];
            sentence = randomElement
            this.sentenceControl.patchValue(sentence)
        } else {
            sentence = this.errorsForm.value.text
        }
        this.http.post(environment.style, { sentences: [sentence] }).pipe(concatMap((styleResp: any) => {
            console.log(styleResp)
            this.analysisResults.model1Label = styleResp.predictions[0].label
            return this.http.post(environment.tone, { sentences: [sentence] }).pipe(tap((toneResp:any) => {
                console.log(toneResp)
                this.analysisResults.model2Label = toneResp.predictions[0].join(',  ')
            }))
        })).subscribe({
            next: () => {
                this.analysisLoading = true
            },
            error:() => {
                this.analysisLoading = true;
                this.error = true;
            }
        })
    }

    goToMainPage() {
        this.router.navigate([''])
    }

}
