import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { environment } from 'src/environments/environment';

@Component({
    selector: 'app-errors-correction-page',
    templateUrl: './errors-correction-page.component.html',
    styleUrls: ['./errors-correction-page.component.scss']
})
export class ErrorsCorrectionPageComponent implements OnInit {

    correctedTextLoading = false;
    correctedTextSet = false;
    error = false;
    correctedText!: string;
    randomSampleList = [
        'krul wladyslaw jagiello zwyciezyl w bitwie pod grunwaldem',
        'bylem w sklepie i kupilem ser szynke i masol',
        'w ktorym roku wybuhla druga wojna swiatowa',
        'reprezentacja polski bedzie grac jutro mecz z niemcami',
        'zwiazek charcerski zorganizowal obchody rocznicy wybuhu wojny',
        'slonce swieci jasno na niebie',
        'lubie jesc pyszne lody w gorace dni',
        'w parku spaceruja ludzie z psami',
        'wczoraj wieczorem obejzalem interesujacy film',
        'jade na wakacje nad piekne jezioro',
        'dzisiaj spotkam sie z przyjaciulmi na kawe',
        'w bibliotece znajduje sie wiele ciekawych ksiazek',
        'nauka jezykuw obcych jest bardzo przydatna',
        'wcoraj zaczalem czytac fascynujaca powiesc',
        'na scianie wisza piekne obrzy',
        'moja ulubiona pora roku to jesien',
        'uwielbiam spacerowac po lesie i podziwiac piękno natury',
        'muj przyjaciel ma czarnego koata o imieniu ciri',
        'dzis wieczorem zamiezam obejrzec nowy odcinek mojego ulubionego serialu',
        'uwielbiam smak swierzego pieczywa prosto z pieca',
        'w niedziele planuę wybrac się na wycieczke rowerowa',
        'maze o podruży do egzotycznego kraju',
        'w moim ogrodzie rosną kolorowe kwiaty wazywa i soczyste owoce',
        'wczoraj wieczorem spotkaem staryh znajomych z czasuw szkolnyh',
        'hciabym naućzyć się grac na gitaze',
        'czy chcialbys pujsc ze mna do parku jutro',
        'czy masz mzoe ohote na spacer po lesie',
        'jezeli boisz sie wysokosci nigdy nei patrz w dul',
        'powiem ci ze uniwersytem adama mickiewica to bardzo dobra uczelnia',
        'mam nadzieje ze wszytsko dobze sie skonczy',
        'czy wiesz o kturej godzinie odjezdza pociog do warszay'
    ]
    errorsForm: FormGroup = this.fb.group({
        text: ['', Validators.required]
    })
    constructor(
        private fb: FormBuilder,
        private http: HttpClient,
        private router: Router
    ) { }

    public get sentenceControl(): FormControl {
        return this.errorsForm.controls['text'] as FormControl
    }


    ngOnInit(): void {
    }

    correctErrors(isRandomSample: boolean): void {
        this.error = false
        let sentence = ''
        this.correctedTextSet = true
        this.correctedTextLoading = false;
        if (isRandomSample) {
            const randomElement = this.randomSampleList[Math.floor(Math.random() * this.randomSampleList.length)];
            sentence = randomElement
            this.sentenceControl.patchValue(sentence)
        } else {
            sentence = this.errorsForm.value.text
        }
        this.http.put(environment.errors, { sentence: sentence }).subscribe({
            next: (resp: any) => {
                this.correctedText = resp.predictions[0].generated_text
                this.correctedTextLoading = true;
            },
            error: () => {
                this.correctedTextLoading = true;
                this.error = true
                console.log('error')
            }
        })


    }

    goToMainPage() {
        this.router.navigate([''])
    }

}
