import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { concatMap, of, tap } from 'rxjs';
import { Chart, ChartConfiguration, ChartOptions, ChartType } from 'chart.js';
import { environment } from 'src/environments/environment';

Chart.defaults.color = '#FFF';

@Component({
    selector: 'app-facebook-analysis',
    templateUrl: './facebook-analysis.component.html',
    styleUrls: ['./facebook-analysis.component.scss']
})
export class FacebookAnalysisComponent implements OnInit {


    comments!: string[];
    results: { sentimentLabel: number, sentence: string, ironyLabel: string }[] = []
    analysisStart = false;
    analysisLoading = false;
    commentStatus = true;
    error = false;
    post!: string;
    exampleOutput = {
        model1Label: 0,
        model2Label: ''
    }
    analysisResults = this.exampleOutput
    public barChartLegend = true;
    public barChartPlugins = [];
    public sentimentBarChartOptions: ChartConfiguration<'bar'>['options'] = {
        responsive: false,
        scales: {
            yAxes: {
                display: true,
            }
        }
    };
    public sentimentBarChartData: ChartConfiguration<'bar'>['data'] = {
        labels: ['Statystyki sentymentu'],
        datasets: []
    };

    public ironyBarChartOptions: ChartConfiguration<'bar'>['options'] = {
        responsive: false,
        scales: {
            yAxes: {
                display: true,
            }
        }
    };
    public ironyBarChartData: ChartConfiguration<'bar'>['data'] = {
        labels: ['Statystyki ironii'],
        datasets: [],
    };

    get link(): FormControl {
        return this.linkForm.controls['link'] as FormControl
    }

    constructor(private router: Router, private fb: FormBuilder, private http: HttpClient) { }

    linkForm: FormGroup = this.fb.group({
        link: ['https://www.facebook.com/SamsungPolska/posts/pfbid0aLx9SLiHxb2VeZy5LkijWyHfsLYLTdijtuTz41r2CALhUWbDUWpYpLVjdZicPaLwl', Validators.required]
    })

    ngOnInit(): void {
    }

    goToMainPage(): void {
        this.router.navigate([''])
    }

    getComments() {
        this.analysisStart = true
        this.analysisLoading = false
        let link = this.link.value
        this.http.post(environment.facebook, { link: link }).pipe(concatMap((facebookResp: any) => {
            if (!facebookResp.status) {
                this.commentStatus = false;
                return of({})
            } else {
                console.log(facebookResp)
                this.commentStatus = true;
                this.post = facebookResp.post
                return this.http.post(environment.style, { sentences: [this.post] }).pipe(concatMap((styleResp: any) => {
                    this.analysisResults.model1Label = styleResp.predictions[0].label
                    return this.http.post(environment.tone, { sentences: [this.post] }).pipe(concatMap((toneResp: any) => {
                        this.analysisResults.model2Label = toneResp.predictions[0].join(',  ')
                        return this.http.post(environment.sentiment, { sentences: facebookResp.sentences }).pipe(concatMap((resp: any) => {
                            this.results = resp.predictions.map((elem: any) => { return { sentimentLabel: elem.label, sentence: elem.sentence } })
                            this.sentimentBarChartData.datasets = [
                                { data: [resp.count_labels.negative], label: String(resp.count_labels.negative) + ' negatywny', backgroundColor: 'rgba(250, 66, 66, 1)', borderRadius: 15,},
                                { data: [resp.count_labels.positive], label: String(resp.count_labels.positive) + ' pozytywny', backgroundColor: '#65dec2', borderRadius: 15, },
                                { data: [resp.count_labels.neutral], label: String(resp.count_labels.neutral) + ' neutralny', backgroundColor: 'rgb(196, 196, 196)', borderRadius: 15, }
                            ]
                            return this.http.post(environment.irony, { sentences: facebookResp.sentences }).pipe(tap((ironyResp: any) => {
                                this.results.forEach((element, i) => {
                                    element.ironyLabel = ironyResp.predictions[i].label
                                });
                                this.ironyBarChartData.datasets = [
                                    { data: [ironyResp.count_labels.irony], label: String(ironyResp.count_labels.irony) + ' ironia', backgroundColor: '#65dec2', borderRadius: 15 },
                                    { data: [ironyResp.count_labels.non_irony], label: String(ironyResp.count_labels.non_irony) + ' brak ironii', backgroundColor: 'rgb(196, 196, 196)', borderRadius: 15, },
                                ]
                            }))
                        }))
                    }))
                }))
            }

        })).subscribe({
            next: () => {
                this.analysisLoading = true
            },
            error: () => {
                this.analysisLoading = true
                this.error = true
                console.log('error')
            }
        })
    }

}
