import { HttpClient } from '@angular/common/http';
import { Component, OnInit } from '@angular/core';
import { FormGroup, Validators, FormBuilder, FormArray } from '@angular/forms';
import { Router } from '@angular/router';
import { Chart, ChartConfiguration, ChartOptions, ChartType } from 'chart.js';
import { environment } from 'src/environments/environment';

Chart.defaults.color = '#FFF';

@Component({
    selector: 'app-irony-analysis',
    templateUrl: './irony-analysis.component.html',
    styleUrls: ['./irony-analysis.component.scss']
})
export class IronyAnalysisComponent implements OnInit {
    public barChartLegend = true;
    public barChartPlugins = [];
    public ironyBarChartOptions: ChartConfiguration<'bar'>['options'] = {
        responsive: false,
        scales: {
            yAxes: {
                display: true,
            }
        }
    };
    public ironyBarChartData: ChartConfiguration<'bar'>['data'] = {
        labels: ['Statystyki ironii'],
        datasets: []
    };

    randomSampleList = [
        "Super, jeszcze jedno zadanie do wykonania. Przecież nie mam nic innego do roboty.",
        "Jasne, że jestem w pełni zainteresowany twoją prezentacją. Właśnie potrzebuję sobie uciąć drzemkę.",
        "No pewnie, że jestem wniebowzięty kolejnym obiadkiem z mikrofalówki. Nic nie smakuje lepiej niż jedzenie pełne konserwantów.",
        "No jasne, że jestem podekscytowany kolejną prezentacją PowerPoint. Czekam na to, jak monotonny może być przekaz.",
        "Oczywiście, że jestem wniebowzięty kolejnym prezentem na Dzień Matki. Potrzebuję jeszcze więcej bibelotów do zbierania kurzu.",
        "Super, jeszcze jedno szkolenie z zasad BHP. Czuję, że moja wiedza w tej dziedzinie nigdy nie jest wystarczająca.",
        "No jasne, że jestem podekscytowany kolejnym spotkaniem przedstawicieli handlowych. Czego jeszcze potrzebuję? Jeszcze więcej gadających ludzi.",
        "Super, jeszcze jeden błąd w kodzie. Moja umiejętność pisania programów jest niezwykła.",
        "Oczywiście, że najbardziej lubię spędzać czas z irytującymi ludźmi. To jest moje ulubione hobby.",
        "Oczywiście, że uwielbiam, kiedy ludzie przeklinają bez przerwy. To jest tak piękne i wzbogacające dla mojego słownictwa.",
        "Jasne, że nie mam nic przeciwko spędzeniu całego dnia na zmywaniu góry naczyń. Przecież nie ma nic lepszego do roboty.",
        "Oczywiście, że jestem wielkim fanem robienia zakupów impulsywnych. Moje konto bankowe uwielbia ten mój talent.",
        "Jasne, że to jest najlepsza piosenka, jaką kiedykolwiek słyszałem. Zwłaszcza ten wspaniały refren, który brzmi jak zakłócenia radiowe.",
        "Oczywiście, że najbardziej lubię, kiedy wszyscy mi przerywają. Moja mowa jest tak porywająca, że trudno się oprzeć.",
        "Tak, pewnie, że jestem mistrzem organizacji. Mój pokój wygląda jak skansen starych gazet i zużytych opakowań po jedzeniu.",
        "No tak, bo wszyscy uwielbiają, kiedy ktoś głośno przeżuwa obok nich.",
        "Tak, pewnie, że nic nie smakuje lepiej niż zimna pizza z dostawy sprzed dwóch dni.",
        "Tak, pewnie, że moje umiejętności taneczne są na poziomie gwiazdy. Przez to ściany się ze mnie śmieją.",
        "Tak, pewnie, że kocham, kiedy mnie ktoś przeklina. To znak, że zrobiłem dobre wrażenie.",
        "No jasne, że moje umiejętności sprzątania są legendarnie złe. Potrafię tylko robić większy bałagan.",
        "Oczywiście, że uwielbiam, kiedy ktoś przerywa mi podczas oglądania ulubionego serialu. To jest tak ekscytujące.",
        "Tak, pewnie, że zawsze od razu znajduję to, czego szukam. Moja intuicja jest niezawodna.",
        "No pewnie, że jestem niezastąpiony w odbijaniu piłki. Zawsze trafia mi w twarz.",
        "Jasne, że zawsze zwracam uwagę na szczegóły. Zwłaszcza, kiedy przeglądam telefon i idę prosto w słup.",
        "Jasne, że jestem mistrzem w zakłócaniu ciszy. Mój talent w rozpraszaniu jest godny podziwu.",
        "Oczywiście, że uwielbiam, kiedy ludzie ignorują moje wiadomości. To sprawia, że czuję się wyjątkowy.",
        "Dzisiaj jest piękna pogoda.",
        "Mam wiele do zrobienia, ale dam radę. Będę pracować skoncentrowanie i efektywnie.",
        "Jestem ekspertem w tym temacie. Spędziłem dużo czasu na nauce i praktyce.",
        "Zasługuję na podwyżkę. Moja praca jest dobrze wykonana i przynosi dobre wyniki.",
        "Jestem zainteresowany twoją prezentacją. Chcę się czegoś nowego nauczyć.",
        "Wykonam tę pracę szybko i starannie. Znam się na tym i mam doświadczenie.",
        "To jest dobra aplikacja, która może mi pomóc w mojej codziennej pracy.",
        "Zaproszenie na piwo o 23:00 brzmi interesująco. Cieszę się, że mogę spędzić czas z przyjaciółmi.",
        "Masz rację. Twoja sugestia jest dobra i warto ją wziąć pod uwagę.",
        "To zadanie jest łatwe. Potrafię je zrobić szybko i bez większych problemów.",
        "Chętnie posłucham twojej historii z wakacji. Zawsze lubię słuchać ciekawych historii.",
        "Pomogę ci z projektem. Razem możemy osiągnąć sukces.",
        "Spotkanie będzie interesujące. Czekam na nowe informacje i możliwość współpracy z innymi.",
        "Ta książka jest naprawdę dobra. Ciekawa fabuła i interesujące postacie.",
        "Zamówię coś smacznego z menu. Dziś mam ochotę na coś wyjątkowego.",
        "Jestem zaangażowany w ten projekt. Chcę wnieść swój wkład i osiągnąć wspólne cele.",
        "Zgadzam się z twoją opinią. Masz rację w tym, co mówisz.",
        "Chętnie wysłucham twojej historii o snach. Zawsze jestem ciekaw innych doświadczeń.",
        "Jestem twoim fanem. Cieszę się, że mogę oglądać twoje sukcesy.",
        "Nie przepadam za spotkaniami rodzinymi, ale ważne jest dla mnie, by być z bliskimi.",
        "Chętnie odwiedzę twoją wystawę sztuki. Interesuję się sztuką i chcę zobaczyć twój talent.",
        "Przeczytam twoją pracę magisterską. Ciekawi mnie temat, który wybrałeś.",
        "Będę słuchać twojego wystąpienia na konferencji. Interesują mnie nowe pomysły i wiedza.",
        "Dotrzymam umówionego terminu. Szanuję czas innych i jestem punktualny.",
        "Czekam na to spotkanie. Liczę na ciekawe prezentacje i nowe informacje.",
        "Zagram w twoim zespole na imprezie. To będzie świetna zabawa i okazja do poznania nowych ludzi.",
    ]

    analysisStart = false;
    analysisLoading = false;
    analysisResults: { label: number, score: number, sentence: string }[] = [];
    error = false;


    sentimentForm: FormGroup = this.fb.group({
        sentences: this.fb.array([
            this.fb.group({
                text: ['', Validators.required]
            })
        ])
    })

    constructor(
        private fb: FormBuilder,
        private http: HttpClient,
        private router: Router
    ) { }

    get sentencesArray(): FormArray {
        return this.sentimentForm.controls['sentences'] as FormArray
    }


    ngOnInit(): void {
        //this.duplicateField()
        //pozdrawiam serdecznie
    }

    analyzeIrony(isRandomSample: boolean) {
        this.error = false
        this.analysisStart = true
        this.analysisLoading = false
        let sentences = []
        if (isRandomSample) {
            const shuffled = this.randomSampleList.sort(() => 0.5 - Math.random());
            sentences = shuffled.slice(0, 5);
        } else {
            let value = this.sentimentForm.value
            sentences = value.sentences.map((value: any) => value.text)
        }
        this.http.post(environment.irony, { sentences: sentences }).subscribe({
            next: (resp: any) => {
                console.log(resp)
                this.analysisLoading = true;
                this.analysisResults = resp.predictions;
                this.ironyBarChartData.datasets = [
                    { data: [resp.count_labels.non_irony], label: String(resp.count_labels.non_irony) + ' brak ironii', backgroundColor: 'rgb(196, 196, 196) ', borderRadius: 15, },
                    { data: [resp.count_labels.irony], label: String(resp.count_labels.irony) + ' ironia', backgroundColor: '#65dec2', borderRadius: 15, },
                ]
            },
            error: () => {
                this.analysisLoading = true
                this.error = true
                console.log('error')
            }
        })

    }

    duplicateField() {
        const sentenceForm = this.fb.group({
            text: ['', Validators.required]
        })
        this.sentencesArray.push(sentenceForm)
    }

    trackByFn(index: any, item: any) {
        return index;
    }

    goToMainPage() {
        this.router.navigate([''])
    }

    resetFields() {
        this.sentencesArray.clear()
        setTimeout(() => {
            this.duplicateField()
        }, 10)
    }

}
