import { ActivatedRoute } from '@angular/router';
import { Component, OnInit } from '@angular/core';
import { ChartConfiguration, ChartOptions, ChartType } from 'chart.js';

export interface Reaction {
    angry: number;
    haha: number;
    happy: number;
    hearth: number;
    like: number;
    ooo: number;
    sad: number;
}

export interface PopularComments {
    comment: string;
    reaction: Reaction;
}

export interface PostAnalysisResult {
    isPositive: boolean;
    reaction: Reaction;
    postCommentCounts: number;
    mostPopularComments: PopularComments[];
    analysisResults: any
};

@Component({
    selector: 'app-post-analysis',
    templateUrl: './post-analysis.component.html',
    styleUrls: ['./post-analysis.component.scss']
})
export class PostAnalysisComponent implements OnInit {
    isHelpNeed = false
    showResult = false
    isPreview = false

    postAnalysisResult: PostAnalysisResult = {
        isPositive: true,
        reaction: {
            angry: 0,
            haha: 0,
            happy: 20,
            hearth: 34,
            like: 56,
            ooo: 2,
            sad: 0
        },
        postCommentCounts: 157,
        mostPopularComments: [{
            comment: 'Ale super reklamka uhuhu',
            reaction: {
                angry: 0,
                haha: 0,
                happy: 0,
                hearth: 4,
                like: 6,
                ooo: 0,
                sad: 0
            },
        }, {
            comment: 'Ale fajne produkty robicie',
            reaction: {
                angry: 0,
                haha: 0,
                happy: 0,
                hearth: 0,
                like: 14,
                ooo: 20,
                sad: 0
            },
        }],
        analysisResults: []
    }

    constructor(private route: ActivatedRoute) { }


    //bar chart
    public barChartLegend = true;
    public barChartPlugins = [];

    public barChartData: ChartConfiguration<'bar'>['data'] = {
        labels: ['Ironia czy coś tam'],
        datasets: [
            { data: [65], label: '65%', backgroundColor: 'rgba(250, 66, 66, 1)', borderRadius: 15, },
            { data: [35], label: '35%', backgroundColor: 'rgba(124, 136, 248, 1)', borderRadius: 15, }
        ]
    };

    public barChartOptions: ChartConfiguration<'bar'>['options'] = {
        responsive: false,
        scales: {
            yAxes: {
                display: false
            }
        }
    };

    //line chart
    public lineChartData: ChartConfiguration<'line'>['data'] = {
        labels: [
            'super',
            'fajny',
            'wykres',

        ],
        datasets: [
            {
                data: [65, 59, 80],
                label: 'Ale wykres ooo',
                fill: true,
                tension: 0.0,
                borderColor: 'black',
                backgroundColor: 'rgba(124, 136, 248, 1)'
            }
        ]
    };
    public lineChartOptions: ChartOptions<'line'> = {
        responsive: false,
        scales: {
            yAxes: {
                display: false
            }
        }
    };
    public lineChartLegend = true;

    //pie
    public pieChartOptions: ChartOptions<'pie'> = {
        responsive: false,
    };
    public pieChartLabels = [['59%'], ['41%']];
    public pieChartDatasets = [{
        data: [41, 59], backgroundColor: ["rgba(124, 136, 248, 1)","rgba(250, 66, 66, 1)"], borderWidth:0
    }];
    public pieChartLegend = true;
    public pieChartPlugins = [];

    ngOnInit(): void {
        if (this.route.snapshot.params['id']) {
            this.isPreview = true;
            this.showResult = true;
        }
    }

}
